import React, { Component, Fragment } from 'react';
import PropTypes from 'prop-types';
import Select from 'react-select';
import { uniqueId, isString } from 'lodash';

class Expression extends Component {

  constructor(props) {
    super(props);
    this.state = { value: props.sources };
  }

  changeOptions = (value) => {
    const options = [
      ...this.state.value,
      {
        label: value,
        value: value,
      },
    ];
    this.setState({ value: options });

  };

  handleChange = (options) => {
    this.setState({ value: (options) });
  }

  handleClick = (event) => {
    this.changeOptions(event.target.value);
  }

  handleKeyPress = (event) => {
    if (event.key === 'Enter') {
      this.changeOptions(Math.abs(event.target.value));
    }
  }

  optionsExpression = () => {
    return this.props.options.map(source => {
      if (isString(source)) {
        return {
          label: source,
          value: uniqueId('expr_'),
        }
      }
      return source;
    });
  };

inputExpression = () => (
  <div>
    {this.props.operator.map(operator => (
      <Fragment key={`button-${operator}`}>
        <input className={this.props.classBtn} type="button" onClick={this.handleClick} value={operator} />
      </Fragment>
    ))}
    <input className={this.props.classInput} type="number" min="0" placeholder="exemple: 1.2" onKeyPress={this.handleKeyPress} />
  </div>
);

render() {
  const { label, name } = this.props;

  return (    
    <div className="react-expression">
      {label &&
        <div>
          <label htmlFor={name}>{label}</label>
          <i> (Press `Enter` for add numeric value)</i>
        </div>
      }
      {this.inputExpression()}
      <Select
        multi   
        name={name}    
        value={this.state.value}
        onChange={this.handleChange}
        options={this.optionsExpression()}
      />
    </div>    
  );
}
}

Expression.propTypes = {
  label: PropTypes.string,
  name: PropTypes.string,  
};

Expression.defaultProps = {
  label: 'Expression',  
  options: [],
  operator: ['+', '-', '/', '*', '(', ')'],
  sources: '',
};

export default Expression;
